<?php

namespace Metropolitan\Tour\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Metropolitan\Tour\Actions\TourAction;
use Metropolitan\Tour\Http\Requests\TourActionRequest;
use Metropolitan\Tour\Http\Resources\TourResource;
use Metropolitan\Tour\Models\Tour;

/**
 * Admin web controller class.
 */
class TourActionController extends BaseController
{

    /**
     * Action controller function for tour.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(TourActionRequest $request, Tour $tour, $action)
    {
        try {
            $request = $request->all();
            $tour = TourAction::run($action, $tour, $request);

            $data = new TourResource($tour);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('tour::tour.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('tour/tour/' . $tour->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('tour/tour/' . $tour->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
