<?php

namespace Metropolitan\Tour\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Exception;
use Metropolitan\Tour\Http\Requests\TourActionsRequest;
use Metropolitan\Tour\Actions\TourActions;

/**
 * Admin web controller class.
 */
class TourActionsController extends BaseController
{

    /**
     * Action controller function for tour.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(TourActionsRequest $request, $action)
    {
        try {
            $tour = TourActions::run($request, $action);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('tour::tour.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('tour/tour/' . $action))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('tour/tour/' . $action))
                ->redirect();
        }
    }
}
