<?php

namespace Metropolitan\Tour\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Illuminate\Support\Str;
use Metropolitan\Tour\Actions\TourExim;
use Metropolitan\Tour\Http\Requests\TourEximRequest;

/**
 * Admin web controller class.
 */
class TourEximController extends BaseController
{
    /**
     * Action controller function for tour.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(TourEximRequest $request, $exim)
    {
        try {
            $function = Str::camel($exim);
            $data = TourExim::$function($request);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('tour:tour.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('tour/tour/' . $exim))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('tour/tour/' . $exim))
                ->redirect();
        }
    }
}
