<?php

namespace Metropolitan\Tour\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Metropolitan\Tour\Http\Resources\TourResource;
use Metropolitan\Tour\Http\Resources\ToursCollection;
use Metropolitan\Tour\Scopes\TourPublicScope;
use Metropolitan\Tour\Models\Tour;

class TourPublicController extends BaseController
{

    /**
     * Show tour's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = Tour::pushScope(new RequestScope())
            ->pushScope(new TourPublicScope())
            ->paginate($pageLimit)
            ->withQueryString();

        $tours = new ToursCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('tour::tour.names'))
            ->view('tour::public.tour.index')
            ->data(compact('tours', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show tour.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = Tour::findBySlug($slug);
        $data = new TourResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('tour::tour.name'))
            ->view('tour::public.tour.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
