<?php

namespace Metropolitan\Tour\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Metropolitan\Tour\Events\TourAction as TourActionEvent;
use Metropolitan\Tour\Notifications\TourAction as TourActionNotification;
use Litepie\Actions\Concerns\AsAction;

class TourAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the TourActionEvent.
     *
     * @param   TourActionEvent  $event
     * @return mixed
     */
    public function handle(TourActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $tour.
     *
     * @param   TourActionEvent  $event
     * @return void
     */
    public function create(TourActionEvent $event)
    {
        $client = $event->tour->client;
        Notification::send($client, new TourActionNotification($event));
    }

    /**
     * Handle the TourActionEvent as a listener.
     *
     * @param   TourActionEvent  $event
     * @return mixed
     */
    public function asListener(TourActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   TourActionEvent  $event
     * @return bool
     */
    private function isAllowed(TourActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
