<?php

namespace Metropolitan\Tour\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Metropolitan\Tour\Events\TourWorkflow as TourWorkflowEvent;
use Metropolitan\Tour\Notifications\TourWorkflow as TourWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class TourWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(TourWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $tour is submitted.
     *
     * @param TourWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(TourWorkflowEvent $event)
    {
        $client = $event->tour->client;
        Notification::send($client, new TourWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $tour is published.
     *
     * @param TourWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(TourWorkflowEvent $event)
    {
        $client = $event->tour->client;
        Notification::send($client, new TourWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $tour is approved.
     *
     * @param TourWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(TourWorkflowEvent $event)
    {
        $client = $event->tour->client;
        Notification::send($client, new TourWorkflowNotification($event));
    }

    /**
     * Handles the $tour workflow event as a listener.
     *
     * @param TourWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(TourWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
