<?php
namespace Metropolitan\Tour\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Metropolitan\Tour\Events\TourAction as TourActionEvent;
use Metropolitan\Tour\Models\Tour;

class TourAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $tour;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param TourActionEvent $tour
     */
    public function __construct(TourActionEvent $tour)
    {
        $this->action = $event->action;
        $this->tour = $tour;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Tour Approved - ' . config('app.name'))
            ->view('tour::tour.email.action', ['data' => $this->tour]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
