<?php

namespace Metropolitan\Tour\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Metropolitan\Tour\Models\Tour;

class TourPolicy
{

    use TourAction;
    use TourExim;

    /**
     * Determine if the given user can view the tour.
     *
     * @param Authenticatable $user
     * @param Tour $tour
     *
     * @return bool
     */
    public function view(Authenticatable $user, Tour $tour)
    {
        if ($authUser->canDo('tour.tour.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $tour->is_owner;
    }

    /**
     * Determine if the given user can create a tour.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('tour.tour.create');
    }

    /**
     * Determine if the given user can update the given tour.
     *
     * @param Authenticatable $user
     * @param Tour $tour
     *
     * @return bool
     */
    public function update(Authenticatable $user, Tour $tour)
    {
        if ($user->canDo('tour.tour.edit') && $user->isAdmin()) {
            return true;
        }

        return $tour->is_owner;
    }

    /**
     * Determine if the given user can delete the given tour.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Tour $tour)
    {
        return $tour->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
