<?php

namespace Metropolitan\Tour\Providers;

use Illuminate\Support\ServiceProvider;
use Metropolitan\Tour\Tours;

class TourServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'tour');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'tour');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();

        $this->app->register(\Metropolitan\Tour\Providers\AuthServiceProvider::class);
        $this->app->register(\Metropolitan\Tour\Providers\RouteServiceProvider::class);
        $this->app->register(\Metropolitan\Tour\Providers\ActionServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('metropolitan.tour', function($app)
        {
            return $this->app->make(Tour::class);
        });
    }

    /**
     * Merges user's and tour's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'metropolitan.tour'
        );
        
        
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/tour.php', 'metropolitan.tour.tour'
        );
    }


    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['metropolitan.tour'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/' => config_path('metropolitan/tour')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/tour')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/tour')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
